@@ -118,20 +118,20 @@ PYBIND11_MODULE(SymSpellCppPy, m) {
                  py::arg("corpus"))
             .def("purge_below_threshold_words", &symspellcpppy::SymSpell::PurgeBelowThresholdWords,
                  "Remove all below threshold words from the dictionary.")
-            .def("lookup", py::overload_cast<xstring, symspellcpppy::Verbosity>(
+            .def("lookup", py::overload_cast<const xstring &, symspellcpppy::Verbosity>(
                     &symspellcpppy::SymSpell::Lookup),
                  " Find suggested spellings for a given input word, using the maximum\n"
                  "    edit distance specified during construction of the SymSpell dictionary.",
                  py::arg("input"),
                  py::arg("verbosity"))
-            .def("lookup", py::overload_cast<xstring, symspellcpppy::Verbosity, int>(
+            .def("lookup", py::overload_cast<const xstring &, symspellcpppy::Verbosity, int>(
                     &symspellcpppy::SymSpell::Lookup),
                  " Find suggested spellings for a given input word, using the maximum\n"
                  "    edit distance provided to the function.",
                  py::arg("input"),
                  py::arg("verbosity"),
                  py::arg("max_edit_distance"))
-            .def("lookup", py::overload_cast<xstring, symspellcpppy::Verbosity, int, bool>(
+            .def("lookup", py::overload_cast<const xstring &, symspellcpppy::Verbosity, int, bool>(
                     &symspellcpppy::SymSpell::Lookup),
                  " Find suggested spellings for a given input word, using the maximum\n"
                  "    edit distance provided to the function and include input word in suggestions, if no words within edit distance found.",
@@ -139,7 +139,7 @@ PYBIND11_MODULE(SymSpellCppPy, m) {
                  py::arg("verbosity"),
                  py::arg("max_edit_distance"),
                  py::arg("include_unknown"))
-            .def("lookup", py::overload_cast<xstring, symspellcpppy::Verbosity, int, bool, bool>(
+            .def("lookup", py::overload_cast<const xstring &, symspellcpppy::Verbosity, int, bool, bool>(
                     &symspellcpppy::SymSpell::Lookup),
                  " Find suggested spellings for a given input word, using the maximum\n"
                  "    edit distance provided to the function and include input word in suggestions, if no words within edit distance found & preserve transfer casing.",
